<!--危险源-报警数据分析统计-->
<template>
  <div class="alarm-data-statistics">
    <public-title title="危险源-报警数据分析统计" />
    <div class="chart-container">
      <div id="alarm-data-statistics-chart" style="width: 100%;height: 100%;" />
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {callThePoliceAnalysisStatistics} from '@/api/device/earlyWarningMonitoring'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'AlarmDataStatistics',
  components: {PublicTitle},
  data() {
    return {
      myChart: null,  // 图表实例对象
      chartData: {}
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('alarm-data-statistics-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    async getChartData() {
      const {value} = await callThePoliceAnalysisStatistics()
      this.chartData = value
      this.$nextTick(_ => this.initEcharts())
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        color: ['#3eadfd', '#ff6e79'],
        graphic: [{
          type: 'group',
          left: '50%',
          top: '57%',
          bounding: 'raw',
          children: [{
            type: 'text',
            style: {
              text: `事件总数\n${this.chartData?.total || 0}`,
              fontSize: 17,
              lineHeight: 28,
              fill: '#36d9c6',
              textVerticalAlign: 'middle',
              textAlign: 'center'
            }
          }]
        }
        ],
        tooltip: {
          trigger: 'item',
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        legend: {
          position: 'center',
          top: 0,
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        series: [
          {
            name: '报警数据分析统计',
            type: 'pie',
            clockwise: false,
            startAngle: 90,
            radius: ['50%', '80%'],
            center: ['50%', '57%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderRadius: 10,
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 3
            },
            data: [
              {
                value: this.chartData?.alearnNum || 0,
                name: '已处理数'
              },
              {
                value: this.chartData?.notNum || 0,
                name: '未处理数'
              }
            ],
            label: {
              normal: {
                show: true,
                position: 'inside',
                formatter: ({percent}) => percent ? percent.toFixed(0) + '%' : '',
                textStyle: {
                  align: 'center',
                  fontSize: 14,
                  fontWeight: 'bolder',
                  color: '#fff'
                }
              }
            }
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.alarm-data-statistics {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }
}
</style>
